Usage examples
==============

.. automodule::  default_value
    :members:
    :undoc-members:
    :show-inheritance:


.. automodule::  kwonly
    :members:
    :undoc-members:
    :show-inheritance:
    
.. automodule::  kwarg_name
    :members:
    :undoc-members:
    :show-inheritance:
